'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_texture_scale_bias'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_texture_scale_bias',error_checker=_errors._error_checker)
GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX=_C('GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX',0x817B)
GL_POST_TEXTURE_FILTER_BIAS_SGIX=_C('GL_POST_TEXTURE_FILTER_BIAS_SGIX',0x8179)
GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX=_C('GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX',0x817C)
GL_POST_TEXTURE_FILTER_SCALE_SGIX=_C('GL_POST_TEXTURE_FILTER_SCALE_SGIX',0x817A)




'''OpenGL extension EXT.vertex_attrib_64bit

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.vertex_attrib_64bit to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides OpenGL shading language support for vertex shader
	inputs with 64-bit floating-point components and OpenGL API support for
	specifying the value of those inputs using vertex array or immediate mode
	entry points.  This builds on the support for general-purpose support for
	64-bit floating-point values in the ARB_gpu_shader_fp64 extension.
	
	This extension provides a new class of vertex attribute functions,
	beginning with "VertexAttribL" ("L" for "long"), that can be used to
	specify attributes with 64-bit floating-point components.  This extension
	provides no automatic type conversion between attribute and shader
	variables; single-precision attributes are not automatically converted to
	double-precision or vice versa.  For shader variables with 64-bit
	component types, the "VertexAttribL" functions must be used to specify
	attribute values.  For other shader variables, the "VertexAttribL"
	functions must not be used.  If a vertex attribute is specified using the
	wrong attribute function, the values of the corresponding shader input are
	undefined.  This approach requiring matching types is identical to that
	used for the "VertexAttribI" functions provided by OpenGL 3.0 and the
	EXT_gpu_shader4 extension.
	
	Additionally, some vertex shader inputs using the wider 64-bit components
	may count double against the implementation-dependent limit on the number
	of vertex shader attribute vectors.  A 64-bit scalar or a two-component
	vector consumes only a single generic vertex attribute; three- and
	four-component "long" may count as two.  This approach is similar to the
	one used in the current GL where matrix attributes consume multiple
	attributes.
	
	Note that 64-bit generic vertex attributes were nominally supported
	beginning with the introduction of vertex shaders in OpenGL 2.0.  However,
	the OpenGL Shading Language at the time had no support for 64-bit data
	types, so any such values were automatically converted to 32-bit.
	
	Support for 64-bit floating-point vertex attributes in this extension can
	be combined with other extensions.  In particular, this extension provides
	an entry point that can be used with EXT_direct_state_access to directly
	set state for any vertex array object.  Also, the related
	NV_vertex_attrib_integer_64bit extension provides an entry point to
	specify bindless vertex attribute arrays with 64-bit components, integer
	or floating-point.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/vertex_attrib_64bit.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.vertex_attrib_64bit import *
from OpenGL.raw.GL.EXT.vertex_attrib_64bit import _EXTENSION_NAME

def glInitVertexAttrib64BitEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glVertexAttribL1dvEXT=wrapper.wrapper(glVertexAttribL1dvEXT).setInputArraySize(
    'v', 1
)
glVertexAttribL2dvEXT=wrapper.wrapper(glVertexAttribL2dvEXT).setInputArraySize(
    'v', 2
)
glVertexAttribL3dvEXT=wrapper.wrapper(glVertexAttribL3dvEXT).setInputArraySize(
    'v', 3
)
glVertexAttribL4dvEXT=wrapper.wrapper(glVertexAttribL4dvEXT).setInputArraySize(
    'v', 4
)
# INPUT glVertexAttribLPointerEXT.pointer size not checked against size
glVertexAttribLPointerEXT=wrapper.wrapper(glVertexAttribLPointerEXT).setInputArraySize(
    'pointer', None
)
glGetVertexAttribLdvEXT=wrapper.wrapper(glGetVertexAttribLdvEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


"""Simple plug-in mechanism to provide replacement for setuptools plugins"""

class Plugin( object ):
    """Base class for plugins to be loaded"""
    loaded = False
    def __init__( self, name, import_path, check = None, **named ):
        """Register the plug-in"""
        self.name = name 
        self.import_path = import_path
        self.check = check
        self.registry.append( self )
        self.__dict__.update( named )
    def load( self ):
        """Attempt to load and return our entry point"""
        try:
            return importByName( self.import_path )
        except ImportError as err:
            return None
    @classmethod
    def match( cls, *args ):
        """Match to return the plugin which is appropriate to load"""
    @classmethod
    def all( cls ):
        """Iterate over all registered plugins"""
        return cls.registry[:]
    @classmethod 
    def by_name( cls, name ):
        for instance in cls.all():
            if instance.name == name:
                return instance 
        return None
    
def importByName( fullName ):
    """Import a class by name"""
    name = fullName.split(".")
    moduleName = name[:-1]
    className = name[-1]
    module = __import__( ".".join(moduleName), {}, {}, moduleName)
    return getattr( module, className )

        
class PlatformPlugin( Plugin ):
    """Platform-level plugin registration"""
    registry = []
    @classmethod
    def match( cls, key ):
        """Determine what platform module to load
        
        key -- (sys.platform,os.name) key to load 
        """
        for possible in key:
            # prefer sys.platform, *then* os.name
            for plugin in cls.registry:
                if plugin.name == possible:
                    return plugin
        raise KeyError( """No platform plugin registered for %s"""%(key,))

class FormatHandler( Plugin ):
    """Data-type storage-format handler"""
    registry = []
    @classmethod
    def match( cls, value ):
        """Lookup appropriate handler based on value (a type)"""
        key = '%s.%s'%( value.__module__, value.__name__ )
        for plugin in cls.registry:
            set = getattr( plugin, 'check', ())
            if set and key in set:
                return plugin
        return None



'''OpenGL extension EXT.multi_draw_indirect

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.multi_draw_indirect to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/multi_draw_indirect.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.multi_draw_indirect import *
from OpenGL.raw.GLES2.EXT.multi_draw_indirect import _EXTENSION_NAME

def glInitMultiDrawIndirectEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glMultiDrawArraysIndirectEXT.indirect size not checked against 'drawcount,stride'
glMultiDrawArraysIndirectEXT=wrapper.wrapper(glMultiDrawArraysIndirectEXT).setInputArraySize(
    'indirect', None
)
# INPUT glMultiDrawElementsIndirectEXT.indirect size not checked against 'drawcount,stride'
glMultiDrawElementsIndirectEXT=wrapper.wrapper(glMultiDrawElementsIndirectEXT).setInputArraySize(
    'indirect', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension KHR.debug

This module customises the behaviour of the 
OpenGL.raw.GL.KHR.debug to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows the GL to notify applications when various events 
	occur that may be useful during application development, debugging and 
	profiling.
	
	These events are represented in the form of enumerable messages with a 
	human-readable string representation. Examples of debug events include 
	incorrect use of the GL, warnings of undefined behavior, and performance 
	warnings.
	
	A message is uniquely identified by a source, a type and an 
	implementation-dependent ID within the source and type pair.
	
	A message's source identifies the origin of the message and can either 
	describe components of the GL, the window system, third-party external 
	sources such as external debuggers, or even the application itself.
	
	The type of the message roughly identifies the nature of the event that 
	caused the message. Examples include errors, performance warnings, 
	warnings about undefined behavior or notifications identifying that the 
	application is within a specific section of the application code.
	
	A message's ID for a given source and type further distinguishes messages 
	within namespaces. For example, an error caused by a negative parameter 
	value or an invalid internal texture format are both errors generated by 
	the API, but would likely have different message IDs.
	
	Each message is also assigned to a severity level that denotes roughly how 
	"important" that message is in comparison to other messages across all 
	sources and types. For example, notification of a GL error would likely 
	have a higher severity than a performance warning due to redundant state 
	changes.
	
	Furthermore, every message contains an implementation-dependent string
	representation that provides a useful description of the event.
	
	Messages are communicated to the application through an application-
	defined callback function that is called by the GL implementation on each 
	debug message. The motivation for the callback routine is to free 
	application developers from actively having to query whether a GL error, 
	or any other debuggable event has happened after each call to a GL 
	function. With a callback, developers can keep their code free of debug 
	checks, set breakpoints in the callback function, and only have to react 
	to messages as they occur. In situations where using a callback is not 
	possible, a message log is also provided that stores only copies of recent 
	messages until they are actively queried. 
	
	To control the volume of debug output, messages can be disabled either 
	individually by ID, or entire sets of messages can be turned off based on 
	combination of source and type, through the entire application code or 
	only section of the code encapsulated in debug groups. A debug group may 
	also be used to annotate the command stream using descriptive texts. 
	
	This extension also defines debug markers, a mechanism for the OpenGL 
	application to annotate the command stream with markers for discrete 
	events.
	
	When profiling or debugging an OpenGL application with a built-in or an 
	external debugger or profiler, it is difficult to relate the commands 
	within the command stream to the elements of the scene or parts of the 
	program code to which they correspond. Debug markers and debug groups help 
	obviate this by allowing applications to specify this link. For example, a 
	debug marker can be used to identify the beginning of a frame in the 
	command stream and a debug group can encapsulate a specific command stream 
	to identify a rendering pass. Debug groups also allow control of the debug 
	outputs volume per section of an application code providing an effective 
	way to handle the massive amount of debug outputs that drivers can 
	generate.
	
	Some existing implementations of ARB_debug_output only expose the
	ARB_debug_output extension string if the context was created with the
	debug flag {GLX|WGL}_CONTEXT_DEBUG_BIT_ARB as specified in 
	{GLX|WGL}_ARB_create_context. The behavior is not obvious when the
	functionality is brought into the OpenGL core specification because the
	extension string and function entry points must always exist.
	
	This extension modifies the existing ARB_debug_output extension to allow 
	implementations to always have an empty message log. The specific messages 
	written to the message log or callback routines are already implementation 
	defined, so this specification simply makes it explicit that it's fine for 
	there to be zero messages generated, even when a GL error occurs, which is 
	useful if the context is non-debug.
	
	Debug output can be enabled and disabled by changing the DEBUG_OUTPUT 
	state. It is implementation defined how much debug output is generated if 
	the context was created without the CONTEXT_DEBUG_BIT set. This is a new 
	query bit added to the existing GL_CONTEXT_FLAGS state to specify whether 
	the context was created with debug enabled.
	
	Finally, this extension defines a mechanism for OpenGL applications to 
	label their objects (textures, buffers, shaders, etc.) with a descriptive 
	string. 
	
	When profiling or debugging an OpenGL application within an external or 
	built-in (debut output API) debugger or profiler it is difficult to 
	identify objects from their object names (integers). 
	
	Even when the object itself is viewed it can be problematic to 
	differentiate between similar objects. Attaching a descriptive string, a 
	label, to an object obviates this difficulty.
	
	The intended purpose of this extension is purely to improve the user 
	experience within OpenGL development tools and application built-in 
	profilers and debuggers. This extension typically improves OpenGL 
	programmers efficiency by allowing them to instantly detect issues and the 
	reason for these issues giving him more time to focus on adding new 
	features to an OpenGL application.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/KHR/debug.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.KHR.debug import *
from OpenGL.raw.GL.KHR.debug import _EXTENSION_NAME

def glInitDebugKHR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDebugMessageControl.ids size not checked against count
glDebugMessageControl=wrapper.wrapper(glDebugMessageControl).setInputArraySize(
    'ids', None
)
# INPUT glDebugMessageInsert.buf size not checked against 'buf,length'
glDebugMessageInsert=wrapper.wrapper(glDebugMessageInsert).setInputArraySize(
    'buf', None
)
glGetDebugMessageLog=wrapper.wrapper(glGetDebugMessageLog).setOutput(
    'ids',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'lengths',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'messageLog',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'severities',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'sources',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'types',size=lambda x:(x,),pnameArg='count',orPassIn=True
)
# INPUT glPushDebugGroup.message size not checked against 'message,length'
glPushDebugGroup=wrapper.wrapper(glPushDebugGroup).setInputArraySize(
    'message', None
)
# INPUT glObjectLabel.label size not checked against 'label,length'
glObjectLabel=wrapper.wrapper(glObjectLabel).setInputArraySize(
    'label', None
)
glGetObjectLabel=wrapper.wrapper(glGetObjectLabel).setOutput(
    'label',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
# INPUT glObjectPtrLabel.label size not checked against 'label,length'
glObjectPtrLabel=wrapper.wrapper(glObjectPtrLabel).setInputArraySize(
    'label', None
)
glGetObjectPtrLabel=wrapper.wrapper(glGetObjectPtrLabel).setOutput(
    'label',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
glGetPointerv=wrapper.wrapper(glGetPointerv).setOutput(
    'params',size=(1,),orPassIn=True
)
# INPUT glGetDebugMessageLogKHR.ids size not checked against count
# INPUT glGetDebugMessageLogKHR.lengths size not checked against count
# INPUT glGetDebugMessageLogKHR.messageLog size not checked against bufSize
# INPUT glGetDebugMessageLogKHR.severities size not checked against count
# INPUT glGetDebugMessageLogKHR.sources size not checked against count
# INPUT glGetDebugMessageLogKHR.types size not checked against count
glGetDebugMessageLogKHR=wrapper.wrapper(glGetDebugMessageLogKHR).setInputArraySize(
    'ids', None
).setInputArraySize(
    'lengths', None
).setInputArraySize(
    'messageLog', None
).setInputArraySize(
    'severities', None
).setInputArraySize(
    'sources', None
).setInputArraySize(
    'types', None
)
# INPUT glGetObjectLabelKHR.label size not checked against bufSize
glGetObjectLabelKHR=wrapper.wrapper(glGetObjectLabelKHR).setInputArraySize(
    'label', None
)
# INPUT glGetObjectPtrLabelKHR.label size not checked against bufSize
glGetObjectPtrLabelKHR=wrapper.wrapper(glGetObjectPtrLabelKHR).setInputArraySize(
    'label', None
).setInputArraySize(
    'length', 1
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.sparse_buffer

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.sparse_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	The ARB_sparse_texture extension adds to GL a mechanism to decouple the
	virtual and physical storage requirements of textures and allows an
	application to create partially populated textures that would
	over-subscribe available graphics memory if made fully resident. This
	extension provides like functionality for buffer objects, allowing
	applications to manage buffer object storage in a similar manner.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/sparse_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.sparse_buffer import *
from OpenGL.raw.GL.ARB.sparse_buffer import _EXTENSION_NAME

def glInitSparseBufferARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.bindless_texture

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.bindless_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows OpenGL applications to access texture objects in
	shaders without first binding each texture to one of a limited number of
	texture image units.  Using this extension, an application can query a
	64-bit unsigned integer texture handle for each texture that it wants to
	access and then use that handle directly in GLSL or assembly-based
	shaders.  The ability to access textures without having to bind and/or
	re-bind them is similar to the capability provided by the
	NV_shader_buffer_load extension that allows shaders to access buffer
	objects without binding them.  In both cases, these extensions
	significantly reduce the amount of API and internal GL driver overhead
	needed to manage resource bindings.
	
	This extension also provides similar capability for the image load, store,
	and atomic functionality provided by OpenGL 4.2 and the
	ARB_shader_image_load_store and EXT_shader_image_load_store extensions,
	where a texture can be accessed without first binding it to an image unit.
	An image handle can be extracted from a texture object using an API with a
	set of parameters similar to those for BindImageTextureEXT.
	
	This extension adds no new data types to GLSL.  Instead, it uses existing
	sampler and image data types and allows them to be populated with texture
	and image handles.  This extension does permit sampler and image data
	types to be used in more contexts than in unextended GLSL 4.00.  In
	particular, sampler and image types may be used as shader inputs/outputs,
	temporary variables, and uniform block members, and may be assigned to by
	shader code.  Constructors are provided to convert unsigned integer values
	to and from sampler and image data types.  Additionally, new APIs are
	provided to load values for sampler and image uniforms with 64-bit
	handle inputs.  The use of existing integer-based Uniform* APIs is still
	permitted, in which case the integer specified will identify a texture
	image or image unit.  For samplers and images with values specified as
	texture image or image units, the GL implemenation will translate the unit
	number to an internal handle as required.
	
	To access texture or image resources using handles, the handles must first
	be made resident.  Accessing a texture or image by handle without first
	making it resident can result in undefined results, including program
	termination.  Since the amount of texture memory required by an
	application may exceed the amount of memory available to the system, this
	extension provides API calls allowing applications to manage overall
	texture memory consumption by making a texture resident and non-resident
	as required.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/bindless_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.bindless_texture import *
from OpenGL.raw.GL.ARB.bindless_texture import _EXTENSION_NAME

def glInitBindlessTextureARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glUniformHandleui64vARB.value size not checked against count
glUniformHandleui64vARB=wrapper.wrapper(glUniformHandleui64vARB).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformHandleui64vARB.values size not checked against count
glProgramUniformHandleui64vARB=wrapper.wrapper(glProgramUniformHandleui64vARB).setInputArraySize(
    'values', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.cull_distance

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.cull_distance to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a new GLSL gl_CullDistance shader output, similar
	to gl_ClipDistance, but used for whole primitive culling.
	
	This new stage in the pipeline is added as part of the primitive clipping
	stage.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/cull_distance.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.cull_distance import *
from OpenGL.raw.GL.ARB.cull_distance import _EXTENSION_NAME

def glInitCullDistanceARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.vertex_preclip

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.vertex_preclip to provide a more 
Python-friendly API

Overview (from the spec)
	
	Certain graphics subsystems are capable of performing fast
	2D viewport or, in some cases, 3D volume "scissoring" operations
	within some coordinate range much faster that the host CPU could
	re-tesselate clipped primitives.
	
	This extension introduces the notion of an extended rasterizable view
	volume that is an expansion of the clip-space view volume.	This volume
	is the space within which a particular graphics system is much more
	efficient at rejecting fragments that lie outside the view volume than
	it is at performing strict view volume clipping.
	
	Clip-checking can be turned on or off through the glEnable/glDisable
	mechanism, and can be further controlled by using glHint.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/vertex_preclip.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.vertex_preclip import *
from OpenGL.raw.GL.SGIX.vertex_preclip import _EXTENSION_NAME

def glInitVertexPreclipSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.paletted_texture

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.paletted_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_paletted_texture defines new texture formats and new calls to
	support the use of paletted textures in OpenGL.  A paletted texture is
	defined by giving both a palette of colors and a set of image data which
	is composed of indices into the palette.  The paletted texture cannot
	function properly without both pieces of information so it increases the
	work required to define a texture.  This is offset by the fact that the
	overall amount of texture data can be reduced dramatically by factoring
	redundant information out of the logical view of the texture and placing
	it in the palette.
	
	Paletted textures provide several advantages over full-color textures:
	
	* As mentioned above, the amount of data required to define a
	texture can be greatly reduced over what would be needed for full-color
	specification.  For example, consider a source texture that has only 256
	distinct colors in a 256 by 256 pixel grid.  Full-color representation
	requires three bytes per pixel, taking 192K of texture data.  By putting
	the distinct colors in a palette only eight bits are required per pixel,
	reducing the 192K to 64K plus 768 bytes for the palette.  Now add an
	alpha channel to the texture.  The full-color representation increases
	by 64K while the paletted version would only increase by 256 bytes.
	This reduction in space required is particularly important for hardware
	accelerators where texture space is limited.
	
	* Paletted textures allow easy reuse of texture data for images
	which require many similar but slightly different colored objects.
	Consider a driving simulation with heavy traffic on the road.  Many of
	the cars will be similar but with different color schemes.  If
	full-color textures are used a separate texture would be needed for each
	color scheme, while paletted textures allow the same basic index data to
	be reused for each car, with a different palette to change the final
	colors.
	
	* Paletted textures also allow use of all the palette tricks
	developed for paletted displays.  Simple animation can be done, along
	with strobing, glowing and other palette-cycling effects.  All of these
	techniques can enhance the visual richness of a scene with very little
	data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/paletted_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.paletted_texture import *
from OpenGL.raw.GL.EXT.paletted_texture import _EXTENSION_NAME

def glInitPalettedTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glColorTableEXT.table size not checked against 'format,type,width'
glColorTableEXT=wrapper.wrapper(glColorTableEXT).setInputArraySize(
    'table', None
)
# OUTPUT glGetColorTableEXT.data COMPSIZE(target, format, type) 
glGetColorTableParameterivEXT=wrapper.wrapper(glGetColorTableParameterivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetColorTableParameterfvEXT=wrapper.wrapper(glGetColorTableParameterfvEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_APPLE_vertex_array_range'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_APPLE_vertex_array_range',error_checker=_errors._error_checker)
GL_STORAGE_CACHED_APPLE=_C('GL_STORAGE_CACHED_APPLE',0x85BE)
GL_STORAGE_CLIENT_APPLE=_C('GL_STORAGE_CLIENT_APPLE',0x85B4)
GL_STORAGE_SHARED_APPLE=_C('GL_STORAGE_SHARED_APPLE',0x85BF)
GL_VERTEX_ARRAY_RANGE_APPLE=_C('GL_VERTEX_ARRAY_RANGE_APPLE',0x851D)
GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE=_C('GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE',0x851E)
GL_VERTEX_ARRAY_RANGE_POINTER_APPLE=_C('GL_VERTEX_ARRAY_RANGE_POINTER_APPLE',0x8521)
GL_VERTEX_ARRAY_STORAGE_HINT_APPLE=_C('GL_VERTEX_ARRAY_STORAGE_HINT_APPLE',0x851F)
@_f
@_p.types(None,_cs.GLsizei,ctypes.c_void_p)
def glFlushVertexArrayRangeAPPLE(length,pointer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glVertexArrayParameteriAPPLE(pname,param):pass
@_f
@_p.types(None,_cs.GLsizei,ctypes.c_void_p)
def glVertexArrayRangeAPPLE(length,pointer):pass



'''OpenGL extension DFX.multisample

This module customises the behaviour of the 
OpenGL.raw.WGL.DFX.multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	    This extension provides a mechanism to antialias all GL primitives:
	    points, lines, polygons, bitmaps, and images. The technique is to
	    sample all primitives multiple times at each pixel. The color sample
	    values are resolved to a single, displayable color each time a pixel
	    is updated, so the antialiasing appears to be automatic at the
	    application level. Because each sample includes depth and stencil
	    information, the depth and stencil functions perform equivalently to
	    the single-sample mode.
	
	    An additional buffer, called the multisample buffer, is added to the
	    framebuffer. Pixel sample values, including color, depth, and
	    stencil values, are stored in this buffer. When the framebuffer
	    includes a multisample buffer, it does not also include separate
	    depth or stencil buffers, even if the multisample buffer does not
	    store depth or stencil values. Color buffers (left/right,
	    front/back, and aux) do coexist with the multisample buffer,
	    however.
	
	    Multisample antialiasing is most valuable for rendering polygons,
	    because it requires no sorting for hidden surface elimination, and
	    it correctly handles adjacent polygons, object silhouettes, and even
	    intersecting polygons. If only points or lines are being rendered,
	    the "smooth" antialiasing mechanism provided by the base GL may
	    result in a higher quality image.
	
	    This extension is a subset of SGIS_multisample. It differs in these
	    key ways:
	
	       * Fragment alpha values are not affected by the fragment sample mask
	       * The sample locations may or may not be fixed. Thus, there is no
		 support for rendering the scene multiple times with different
		 sample points.
	       * Fragment masks are not computed for images or for bitmasks.
	
	    Because of these differences a new extension was created. However,
	    it is not expected that this extension will co-exist with
	    SGIS_multisample. Because of this and the fact that there are only
	    32 push/pop bits the MULTISAMPLE_BIT_SGIS state value is the same as
	    MUTLISAMPLE_BIT_3DFX.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/DFX/multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.DFX.multisample import *
from OpenGL.raw.WGL.DFX.multisample import _EXTENSION_NAME

def glInitMultisampleDFX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_stream_fifo'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_stream_fifo',error_checker=_errors._error_checker)
EGL_STREAM_FIFO_LENGTH_KHR=_C('EGL_STREAM_FIFO_LENGTH_KHR',0x31FC)
EGL_STREAM_TIME_CONSUMER_KHR=_C('EGL_STREAM_TIME_CONSUMER_KHR',0x31FE)
EGL_STREAM_TIME_NOW_KHR=_C('EGL_STREAM_TIME_NOW_KHR',0x31FD)
EGL_STREAM_TIME_PRODUCER_KHR=_C('EGL_STREAM_TIME_PRODUCER_KHR',0x31FF)
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLenum,arrays.GLuint64Array)
def eglQueryStreamTimeKHR(dpy,stream,attribute,value):pass



'''OpenGL extension VERSION.GL_3_2

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_3_2 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_3_2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_3_2 import *
from OpenGL.raw.GL.VERSION.GL_3_2 import _EXTENSION_NAME

def glInitGl32VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawElementsBaseVertex.indices size not checked against 'count,type'
glDrawElementsBaseVertex=wrapper.wrapper(glDrawElementsBaseVertex).setInputArraySize(
    'indices', None
)
# INPUT glDrawRangeElementsBaseVertex.indices size not checked against 'count,type'
glDrawRangeElementsBaseVertex=wrapper.wrapper(glDrawRangeElementsBaseVertex).setInputArraySize(
    'indices', None
)
# INPUT glDrawElementsInstancedBaseVertex.indices size not checked against 'count,type'
glDrawElementsInstancedBaseVertex=wrapper.wrapper(glDrawElementsInstancedBaseVertex).setInputArraySize(
    'indices', None
)
# INPUT glMultiDrawElementsBaseVertex.basevertex size not checked against 'drawcount'
# INPUT glMultiDrawElementsBaseVertex.count size not checked against 'drawcount'
# INPUT glMultiDrawElementsBaseVertex.indices size not checked against 'drawcount'
glMultiDrawElementsBaseVertex=wrapper.wrapper(glMultiDrawElementsBaseVertex).setInputArraySize(
    'basevertex', None
).setInputArraySize(
    'count', None
).setInputArraySize(
    'indices', None
)
glGetInteger64v=wrapper.wrapper(glGetInteger64v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetSynciv=wrapper.wrapper(glGetSynciv).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'values',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
glGetInteger64i_v=wrapper.wrapper(glGetInteger64i_v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
glGetBufferParameteri64v=wrapper.wrapper(glGetBufferParameteri64v).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetMultisamplefv=wrapper.wrapper(glGetMultisamplefv).setOutput(
    'val',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SUN_mesh_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SUN_mesh_array',error_checker=_errors._error_checker)
GL_QUAD_MESH_SUN=_C('GL_QUAD_MESH_SUN',0x8614)
GL_TRIANGLE_MESH_SUN=_C('GL_TRIANGLE_MESH_SUN',0x8615)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glDrawMeshArraysSUN(mode,first,count,width):pass



'''OpenGL extension EXT.vertex_array

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.vertex_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the ability to specify multiple geometric primitives
	with very few subroutine calls.  Instead of calling an OpenGL procedure
	to pass each individual vertex, normal, or color, separate arrays
	of vertexes, normals, and colors are prespecified, and are used to
	define a sequence of primitives (all of the same type) when a single
	call is made to DrawArraysEXT.  A stride mechanism is provided so that
	an application can choose to keep all vertex data staggered in a
	single array, or sparsely in separate arrays.  Single-array storage
	may optimize performance on some implementations.
	
	This extension also supports the rendering of individual array elements,
	each specified as an index into the enabled arrays.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/vertex_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.vertex_array import *
from OpenGL.raw.GL.EXT.vertex_array import _EXTENSION_NAME

def glInitVertexArrayEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glColorPointerEXT.pointer size not checked against 'size,type,stride,count'
glColorPointerEXT=wrapper.wrapper(glColorPointerEXT).setInputArraySize(
    'pointer', None
)
# INPUT glEdgeFlagPointerEXT.pointer size not checked against 'stride,count'
glEdgeFlagPointerEXT=wrapper.wrapper(glEdgeFlagPointerEXT).setInputArraySize(
    'pointer', None
)
glGetPointervEXT=wrapper.wrapper(glGetPointervEXT).setOutput(
    'params',size=(1,),orPassIn=True
)
# INPUT glIndexPointerEXT.pointer size not checked against 'type,stride,count'
glIndexPointerEXT=wrapper.wrapper(glIndexPointerEXT).setInputArraySize(
    'pointer', None
)
# INPUT glNormalPointerEXT.pointer size not checked against 'type,stride,count'
glNormalPointerEXT=wrapper.wrapper(glNormalPointerEXT).setInputArraySize(
    'pointer', None
)
# INPUT glTexCoordPointerEXT.pointer size not checked against 'size,type,stride,count'
glTexCoordPointerEXT=wrapper.wrapper(glTexCoordPointerEXT).setInputArraySize(
    'pointer', None
)
# INPUT glVertexPointerEXT.pointer size not checked against 'size,type,stride,count'
glVertexPointerEXT=wrapper.wrapper(glVertexPointerEXT).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension SUN.global_alpha

This module customises the behaviour of the 
OpenGL.raw.GL.SUN.global_alpha to provide a more 
Python-friendly API

Overview (from the spec)
	
	Transparency is done in OpenGL using alpha blending. An alpha value
	of 0.0 is used for fully transparent objects, while an alpha value
	of 1.0 is used for fully opaque objects.  A value of 0.25 is 75%
	transparent, and so on.
	
	OpenGL defines alpha as a component of the vertex color state.
	Whenever a color is set, the alpha component is set along with the
	red, green, and blue components.  This means that transparency
	can't be changed for primitives with per-vertex colors without
	modifying the color of each vertex, replacing the old alpha
	component with the new alpha component.  This can be very expensive
	for objects that are drawn using vertex arrays; it all but
	precludes the use of display lists.
	
	This extension defines a new global alpha attribute that can be
	used to specify an alpha factor that is independent from the alpha
	component of the color value.  The global alpha factor is
	multiplied by the fragment's alpha value after primitive
	rasterization and prior to texture mapping, replacing the
	fragment's alpha value.  The global alpha extension is only
	specified in RGBA mode and must be applied prior to any texture
	mapping operation.  It is enabled by a new GLOBAL_ALPHA flag.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SUN/global_alpha.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SUN.global_alpha import *
from OpenGL.raw.GL.SUN.global_alpha import _EXTENSION_NAME

def glInitGlobalAlphaSUN():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_compressed_texture_pixel_storage'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_compressed_texture_pixel_storage',error_checker=_errors._error_checker)
GL_PACK_COMPRESSED_BLOCK_DEPTH=_C('GL_PACK_COMPRESSED_BLOCK_DEPTH',0x912D)
GL_PACK_COMPRESSED_BLOCK_HEIGHT=_C('GL_PACK_COMPRESSED_BLOCK_HEIGHT',0x912C)
GL_PACK_COMPRESSED_BLOCK_SIZE=_C('GL_PACK_COMPRESSED_BLOCK_SIZE',0x912E)
GL_PACK_COMPRESSED_BLOCK_WIDTH=_C('GL_PACK_COMPRESSED_BLOCK_WIDTH',0x912B)
GL_UNPACK_COMPRESSED_BLOCK_DEPTH=_C('GL_UNPACK_COMPRESSED_BLOCK_DEPTH',0x9129)
GL_UNPACK_COMPRESSED_BLOCK_HEIGHT=_C('GL_UNPACK_COMPRESSED_BLOCK_HEIGHT',0x9128)
GL_UNPACK_COMPRESSED_BLOCK_SIZE=_C('GL_UNPACK_COMPRESSED_BLOCK_SIZE',0x912A)
GL_UNPACK_COMPRESSED_BLOCK_WIDTH=_C('GL_UNPACK_COMPRESSED_BLOCK_WIDTH',0x9127)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_object',error_checker=_errors._error_checker)
GL_TEXTURE_1D_BINDING_EXT=_C('GL_TEXTURE_1D_BINDING_EXT',0x8068)
GL_TEXTURE_2D_BINDING_EXT=_C('GL_TEXTURE_2D_BINDING_EXT',0x8069)
GL_TEXTURE_3D_BINDING_EXT=_C('GL_TEXTURE_3D_BINDING_EXT',0x806A)
GL_TEXTURE_PRIORITY_EXT=_C('GL_TEXTURE_PRIORITY_EXT',0x8066)
GL_TEXTURE_RESIDENT_EXT=_C('GL_TEXTURE_RESIDENT_EXT',0x8067)
@_f
@_p.types(_cs.GLboolean,_cs.GLsizei,arrays.GLuintArray,arrays.GLbooleanArray)
def glAreTexturesResidentEXT(n,textures,residences):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindTextureEXT(target,texture):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteTexturesEXT(n,textures):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenTexturesEXT(n,textures):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsTextureEXT(texture):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray,arrays.GLclampfArray)
def glPrioritizeTexturesEXT(n,textures,priorities):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_interleaved_elements'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_interleaved_elements',error_checker=_errors._error_checker)
GL_ALPHA=_C('GL_ALPHA',0x1906)
GL_BLUE=_C('GL_BLUE',0x1905)
GL_GREEN=_C('GL_GREEN',0x1904)
GL_RED=_C('GL_RED',0x1903)
GL_RG16UI=_C('GL_RG16UI',0x823A)
GL_RG8UI=_C('GL_RG8UI',0x8238)
GL_RGBA8UI=_C('GL_RGBA8UI',0x8D7C)
GL_VERTEX_ELEMENT_SWIZZLE_AMD=_C('GL_VERTEX_ELEMENT_SWIZZLE_AMD',0x91A4)
GL_VERTEX_ID_SWIZZLE_AMD=_C('GL_VERTEX_ID_SWIZZLE_AMD',0x91A5)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glVertexAttribParameteriAMD(index,pname,param):pass



'''OpenGL extension EXT.framebuffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.framebuffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a simple interface for drawing to rendering
	destinations other than the buffers provided to the GL by the
	window-system.
	
	In this extension, these newly defined rendering destinations are
	known collectively as "framebuffer-attachable images".  This
	extension provides a mechanism for attaching framebuffer-attachable
	images to the GL framebuffer as one of the standard GL logical
	buffers: color, depth, and stencil.  (Attaching a
	framebuffer-attachable image to the accum logical buffer is left for
	a future extension to define).  When a framebuffer-attachable image
	is attached to the framebuffer, it is used as the source and
	destination of fragment operations as described in Chapter 4.
	
	By allowing the use of a framebuffer-attachable image as a rendering
	destination, this extension enables a form of "offscreen" rendering.
	Furthermore, "render to texture" is supported by allowing the images
	of a texture to be used as framebuffer-attachable images.  A
	particular image of a texture object is selected for use as a
	framebuffer-attachable image by specifying the mipmap level, cube
	map face (for a cube map texture), and z-offset (for a 3D texture)
	that identifies the image.  The "render to texture" semantics of
	this extension are similar to performing traditional rendering to
	the framebuffer, followed immediately by a call to CopyTexSubImage.
	However, by using this extension instead, an application can achieve
	the same effect, but with the advantage that the GL can usually
	eliminate the data copy that would have been incurred by calling
	CopyTexSubImage.
	
	This extension also defines a new GL object type, called a
	"renderbuffer", which encapsulates a single 2D pixel image.  The
	image of renderbuffer can be used as a framebuffer-attachable image
	for generalized offscreen rendering and it also provides a means to
	support rendering to GL logical buffer types which have no
	corresponding texture format (stencil, accum, etc).  A renderbuffer
	is similar to a texture in that both renderbuffers and textures can
	be independently allocated and shared among multiple contexts.  The
	framework defined by this extension is general enough that support
	for attaching images from GL objects other than textures and
	renderbuffers could be added by layered extensions.
	
	To facilitate efficient switching between collections of
	framebuffer-attachable images, this extension introduces another new
	GL object, called a framebuffer object.  A framebuffer object
	contains the state that defines the traditional GL framebuffer,
	including its set of images.  Prior to this extension, it was the
	window-system which defined and managed this collection of images,
	traditionally by grouping them into a "drawable".  The window-system
	API's would also provide a function (i.e., wglMakeCurrent,
	glXMakeCurrent, aglSetDrawable, etc.) to bind a drawable with a GL
	context (as is done in the WGL_ARB_pbuffer extension).  In this
	extension however, this functionality is subsumed by the GL and the
	GL provides the function BindFramebufferEXT to bind a framebuffer
	object to the current context.  Later, the context can bind back to
	the window-system-provided framebuffer in order to display rendered
	content.
	
	Previous extensions that enabled rendering to a texture have been
	much more complicated.  One example is the combination of
	ARB_pbuffer and ARB_render_texture, both of which are window-system
	extensions.  This combination requires calling MakeCurrent, an
	operation that may be expensive, to switch between the window and
	the pbuffer drawables.  An application must create one pbuffer per
	renderable texture in order to portably use ARB_render_texture.  An
	application must maintain at least one GL context per texture
	format, because each context can only operate on a single
	pixelformat or FBConfig.  All of these characteristics make
	ARB_render_texture both inefficient and cumbersome to use.
	
	EXT_framebuffer_object, on the other hand, is both simpler to use
	and more efficient than ARB_render_texture.  The
	EXT_framebuffer_object API is contained wholly within the GL API and
	has no (non-portable) window-system components.  Under
	EXT_framebuffer_object, it is not necessary to create a second GL
	context when rendering to a texture image whose format differs from
	that of the window.  Finally, unlike the pbuffers of
	ARB_render_texture, a single framebuffer object can facilitate
	rendering to an unlimited number of texture objects.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/framebuffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.framebuffer_object import *
from OpenGL.raw.GL.EXT.framebuffer_object import _EXTENSION_NAME

def glInitFramebufferObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDeleteRenderbuffersEXT.renderbuffers size not checked against n
glDeleteRenderbuffersEXT=wrapper.wrapper(glDeleteRenderbuffersEXT).setInputArraySize(
    'renderbuffers', None
)
glGenRenderbuffersEXT=wrapper.wrapper(glGenRenderbuffersEXT).setOutput(
    'renderbuffers',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetRenderbufferParameterivEXT=wrapper.wrapper(glGetRenderbufferParameterivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glDeleteFramebuffersEXT.framebuffers size not checked against n
glDeleteFramebuffersEXT=wrapper.wrapper(glDeleteFramebuffersEXT).setInputArraySize(
    'framebuffers', None
)
glGenFramebuffersEXT=wrapper.wrapper(glGenFramebuffersEXT).setOutput(
    'framebuffers',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetFramebufferAttachmentParameterivEXT=wrapper.wrapper(glGetFramebufferAttachmentParameterivEXT).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy as _lazy 

glGenFramebuffersEXT = wrapper.wrapper(glGenFramebuffersEXT).setOutput(
                'framebuffers', 
                lambda x: (x,), 
                'n', orPassIn=True)
                
glGenRenderbuffersEXT = wrapper.wrapper(glGenRenderbuffersEXT).setOutput(
                'renderbuffers', 
                lambda x: (x,), 
                'n', orPassIn=True)

@_lazy( glDeleteFramebuffersEXT )
def glDeleteFramebuffersEXT( baseOperation, n, framebuffers=None ):
    """glDeleteFramebuffersEXT( framebuffers ) -> None 
    """
    if framebuffers is None:
        framebuffers = arrays.GLuintArray.asArray( n )
        n = arrays.GLuintArray.arraySize( framebuffers )
    return baseOperation( n, framebuffers )



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_point_parameters'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_point_parameters',error_checker=_errors._error_checker)
GL_DISTANCE_ATTENUATION_EXT=_C('GL_DISTANCE_ATTENUATION_EXT',0x8129)
GL_POINT_FADE_THRESHOLD_SIZE_EXT=_C('GL_POINT_FADE_THRESHOLD_SIZE_EXT',0x8128)
GL_POINT_SIZE_MAX_EXT=_C('GL_POINT_SIZE_MAX_EXT',0x8127)
GL_POINT_SIZE_MIN_EXT=_C('GL_POINT_SIZE_MIN_EXT',0x8126)
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPointParameterfEXT(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glPointParameterfvEXT(pname,params):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture',error_checker=_errors._error_checker)
GL_ALPHA12_EXT=_C('GL_ALPHA12_EXT',0x803D)
GL_ALPHA16_EXT=_C('GL_ALPHA16_EXT',0x803E)
GL_ALPHA4_EXT=_C('GL_ALPHA4_EXT',0x803B)
GL_ALPHA8_EXT=_C('GL_ALPHA8_EXT',0x803C)
GL_INTENSITY12_EXT=_C('GL_INTENSITY12_EXT',0x804C)
GL_INTENSITY16_EXT=_C('GL_INTENSITY16_EXT',0x804D)
GL_INTENSITY4_EXT=_C('GL_INTENSITY4_EXT',0x804A)
GL_INTENSITY8_EXT=_C('GL_INTENSITY8_EXT',0x804B)
GL_INTENSITY_EXT=_C('GL_INTENSITY_EXT',0x8049)
GL_LUMINANCE12_ALPHA12_EXT=_C('GL_LUMINANCE12_ALPHA12_EXT',0x8047)
GL_LUMINANCE12_ALPHA4_EXT=_C('GL_LUMINANCE12_ALPHA4_EXT',0x8046)
GL_LUMINANCE12_EXT=_C('GL_LUMINANCE12_EXT',0x8041)
GL_LUMINANCE16_ALPHA16_EXT=_C('GL_LUMINANCE16_ALPHA16_EXT',0x8048)
GL_LUMINANCE16_EXT=_C('GL_LUMINANCE16_EXT',0x8042)
GL_LUMINANCE4_ALPHA4_EXT=_C('GL_LUMINANCE4_ALPHA4_EXT',0x8043)
GL_LUMINANCE4_EXT=_C('GL_LUMINANCE4_EXT',0x803F)
GL_LUMINANCE6_ALPHA2_EXT=_C('GL_LUMINANCE6_ALPHA2_EXT',0x8044)
GL_LUMINANCE8_ALPHA8_EXT=_C('GL_LUMINANCE8_ALPHA8_EXT',0x8045)
GL_LUMINANCE8_EXT=_C('GL_LUMINANCE8_EXT',0x8040)
GL_PROXY_TEXTURE_1D_EXT=_C('GL_PROXY_TEXTURE_1D_EXT',0x8063)
GL_PROXY_TEXTURE_2D_EXT=_C('GL_PROXY_TEXTURE_2D_EXT',0x8064)
GL_REPLACE_EXT=_C('GL_REPLACE_EXT',0x8062)
GL_RGB10_A2_EXT=_C('GL_RGB10_A2_EXT',0x8059)
GL_RGB10_EXT=_C('GL_RGB10_EXT',0x8052)
GL_RGB12_EXT=_C('GL_RGB12_EXT',0x8053)
GL_RGB16_EXT=_C('GL_RGB16_EXT',0x8054)
GL_RGB2_EXT=_C('GL_RGB2_EXT',0x804E)
GL_RGB4_EXT=_C('GL_RGB4_EXT',0x804F)
GL_RGB5_A1_EXT=_C('GL_RGB5_A1_EXT',0x8057)
GL_RGB5_EXT=_C('GL_RGB5_EXT',0x8050)
GL_RGB8_EXT=_C('GL_RGB8_EXT',0x8051)
GL_RGBA12_EXT=_C('GL_RGBA12_EXT',0x805A)
GL_RGBA16_EXT=_C('GL_RGBA16_EXT',0x805B)
GL_RGBA2_EXT=_C('GL_RGBA2_EXT',0x8055)
GL_RGBA4_EXT=_C('GL_RGBA4_EXT',0x8056)
GL_RGBA8_EXT=_C('GL_RGBA8_EXT',0x8058)
GL_TEXTURE_ALPHA_SIZE_EXT=_C('GL_TEXTURE_ALPHA_SIZE_EXT',0x805F)
GL_TEXTURE_BLUE_SIZE_EXT=_C('GL_TEXTURE_BLUE_SIZE_EXT',0x805E)
GL_TEXTURE_GREEN_SIZE_EXT=_C('GL_TEXTURE_GREEN_SIZE_EXT',0x805D)
GL_TEXTURE_INTENSITY_SIZE_EXT=_C('GL_TEXTURE_INTENSITY_SIZE_EXT',0x8061)
GL_TEXTURE_LUMINANCE_SIZE_EXT=_C('GL_TEXTURE_LUMINANCE_SIZE_EXT',0x8060)
GL_TEXTURE_RED_SIZE_EXT=_C('GL_TEXTURE_RED_SIZE_EXT',0x805C)
GL_TEXTURE_TOO_LARGE_EXT=_C('GL_TEXTURE_TOO_LARGE_EXT',0x8065)




# -*- coding: iso-8859-1 -*-
"""Raw (C-style) API for OpenGL.GLUT

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw.GLUT.constants import *

from ctypes import *
from OpenGL._bytes import unicode
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid
from OpenGL.raw.GL._types import (
    GLint,
    GLenum,
    GLdouble,
    GLfloat,
)

if hasattr( platform.PLATFORM, 'GLUT_CALLBACK_TYPE' ):
    # it's *always* CFUNCTYPE, AFAICT
    CALLBACK_FUNCTION_TYPE = platform.PLATFORM.GLUT_CALLBACK_TYPE
else:
    CALLBACK_FUNCTION_TYPE = platform.PLATFORM.functionTypeFor( platform.PLATFORM.GLUT )

class STRING( c_char_p ):
    @classmethod
    def from_param( cls, value ):
        if isinstance( value, unicode ):
            value = value.encode( 'utf-8' )
        return c_char_p.from_param( value )


# /usr/include/GL/freeglut_std.h 445
glutAddMenuEntry = platform.createBaseFunction( 
    'glutAddMenuEntry', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[STRING,c_int],
    doc='glutAddMenuEntry( STRING(label), c_int(value) ) -> None', 
    argNames=('label', 'value'),
)


# /usr/include/GL/freeglut_std.h 446
glutAddSubMenu = platform.createBaseFunction( 
    'glutAddSubMenu', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[STRING,c_int],
    doc='glutAddSubMenu( STRING(label), c_int(subMenu) ) -> None', 
    argNames=('label', 'subMenu'),
)


# /usr/include/GL/freeglut_std.h 450
glutAttachMenu = platform.createBaseFunction( 
    'glutAttachMenu', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutAttachMenu( c_int(button) ) -> None', 
    argNames=('button',),
)


# /usr/include/GL/freeglut_std.h 499
glutBitmapCharacter = platform.createBaseFunction( 
    'glutBitmapCharacter', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_void_p,c_int],
    doc='glutBitmapCharacter( c_void_p(font), c_int(character) ) -> None', 
    argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 503
glutBitmapLength = platform.createBaseFunction( 
    'glutBitmapLength', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[c_void_p,POINTER(c_ubyte)],
    doc='glutBitmapLength( c_void_p(font), POINTER(c_ubyte)(string) ) -> c_int', 
    argNames=('font', 'string'),
)


# /usr/include/GL/freeglut_std.h 500
glutBitmapWidth = platform.createBaseFunction( 
    'glutBitmapWidth', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[c_void_p,c_int],
    doc='glutBitmapWidth( c_void_p(font), c_int(character) ) -> c_int', 
    argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 483
glutButtonBoxFunc = platform.createBaseFunction( 
    'glutButtonBoxFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutButtonBoxFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 447
glutChangeToMenuEntry = platform.createBaseFunction( 
    'glutChangeToMenuEntry', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,STRING,c_int],
    doc='glutChangeToMenuEntry( c_int(item), STRING(label), c_int(value) ) -> None', 
    argNames=('item', 'label', 'value'),
)


# /usr/include/GL/freeglut_std.h 448
glutChangeToSubMenu = platform.createBaseFunction( 
    'glutChangeToSubMenu', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,STRING,c_int],
    doc='glutChangeToSubMenu( c_int(item), STRING(label), c_int(value) ) -> None', 
    argNames=('item', 'label', 'value'),
)


# /usr/include/GL/freeglut_std.h 555
glutCopyColormap = platform.createBaseFunction( 
    'glutCopyColormap', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutCopyColormap( c_int(window) ) -> None', 
    argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 441
glutCreateMenu = platform.createBaseFunction( 
    'glutCreateMenu', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[CALLBACK_FUNCTION_TYPE(c_int, c_int)],
    doc='glutCreateMenu( FUNCTION_TYPE(c_int, c_int)(callback) ) -> c_int', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 399
glutCreateSubWindow = platform.createBaseFunction( 
    'glutCreateSubWindow', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[c_int,c_int,c_int,c_int,c_int],
    doc='glutCreateSubWindow( c_int(window), c_int(x), c_int(y), c_int(width), c_int(height) ) -> c_int', 
    argNames=('window', 'x', 'y', 'width', 'height'),
)


# /usr/include/GL/freeglut_std.h 398
glutCreateWindow = platform.createBaseFunction( 
    'glutCreateWindow', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[STRING],
    doc='glutCreateWindow( STRING(title) ) -> c_int', 
    argNames=('title',),
)


# /usr/include/GL/freeglut_std.h 442
glutDestroyMenu = platform.createBaseFunction( 
    'glutDestroyMenu', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutDestroyMenu( c_int(menu) ) -> None', 
    argNames=('menu',),
)


# /usr/include/GL/freeglut_std.h 400
glutDestroyWindow = platform.createBaseFunction( 
    'glutDestroyWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutDestroyWindow( c_int(window) ) -> None', 
    argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 451
glutDetachMenu = platform.createBaseFunction( 
    'glutDetachMenu', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutDetachMenu( c_int(button) ) -> None', 
    argNames=('button',),
)


# /usr/include/GL/freeglut_std.h 492
glutDeviceGet = platform.createBaseFunction( 
    'glutDeviceGet', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[GLenum],
    doc='glutDeviceGet( GLenum(query) ) -> c_int', 
    argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 484
glutDialsFunc = platform.createBaseFunction( 
    'glutDialsFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutDialsFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 466
glutDisplayFunc = platform.createBaseFunction( 
    'glutDisplayFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None)],
    doc='glutDisplayFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 537
glutEnterGameMode = platform.createBaseFunction( 
    'glutEnterGameMode', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[],
    doc='glutEnterGameMode(  ) -> c_int', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 470
glutEntryFunc = platform.createBaseFunction( 
    'glutEntryFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int)],
    doc='glutEntryFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 430
glutEstablishOverlay = platform.createBaseFunction( 
    'glutEstablishOverlay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutEstablishOverlay(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 567
glutExtensionSupported = platform.createBaseFunction( 
    'glutExtensionSupported', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[STRING],
    doc='glutExtensionSupported( STRING(extension) ) -> c_int', 
    argNames=('extension',),
)


# /usr/include/GL/freeglut_std.h 562
glutForceJoystickFunc = platform.createBaseFunction( 
    'glutForceJoystickFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutForceJoystickFunc(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 412
glutFullScreen = platform.createBaseFunction( 
    'glutFullScreen', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutFullScreen(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 539
glutGameModeGet = platform.createBaseFunction( 
    'glutGameModeGet', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[GLenum],
    doc='glutGameModeGet( GLenum(query) ) -> c_int', 
    argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 536
glutGameModeString = platform.createBaseFunction( 
    'glutGameModeString', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[STRING],
    doc='glutGameModeString( STRING(string) ) -> None', 
    argNames=('string',),
)


# /usr/include/GL/freeglut_std.h 491
glutGet = platform.createBaseFunction( 
    'glutGet', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[GLenum],
    doc='glutGet( GLenum(query) ) -> c_int', 
    argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 554
glutGetColor = platform.createBaseFunction( 
    'glutGetColor', dll=platform.PLATFORM.GLUT, resultType=GLfloat, 
    argTypes=[c_int,c_int],
    doc='glutGetColor( c_int(color), c_int(component) ) -> GLfloat', 
    argNames=('color', 'component'),
)


# /usr/include/GL/freeglut_std.h 443
glutGetMenu = platform.createBaseFunction( 
    'glutGetMenu', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[],
    doc='glutGetMenu(  ) -> c_int', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 493
glutGetModifiers = platform.createBaseFunction( 
    'glutGetModifiers', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[],
    doc='glutGetModifiers(  ) -> c_int', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 402
glutGetWindow = platform.createBaseFunction( 
    'glutGetWindow', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[],
    doc='glutGetWindow(  ) -> c_int', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 436
glutHideOverlay = platform.createBaseFunction( 
    'glutHideOverlay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutHideOverlay(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 408
glutHideWindow = platform.createBaseFunction( 
    'glutHideWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutHideWindow(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 409
glutIconifyWindow = platform.createBaseFunction( 
    'glutIconifyWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutIconifyWindow(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 457
glutIdleFunc = platform.createBaseFunction( 
    'glutIdleFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None)],
    doc='glutIdleFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 560
glutIgnoreKeyRepeat = platform.createBaseFunction( 
    'glutIgnoreKeyRepeat', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutIgnoreKeyRepeat( c_int(ignore) ) -> None', 
    argNames=('ignore',),
)


# /usr/include/GL/freeglut_std.h 384
glutInit = platform.createBaseFunction( 
    'glutInit', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[POINTER(c_int),POINTER(STRING)],
    doc='glutInit( POINTER(c_int)(pargc), POINTER(STRING)(argv) ) -> None', 
    argNames=('pargc', 'argv'),
)


# /usr/include/GL/freeglut_std.h 387
glutInitDisplayMode = platform.createBaseFunction( 
    'glutInitDisplayMode', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_uint],
    doc='glutInitDisplayMode( c_uint(displayMode) ) -> None', 
    argNames=('displayMode',),
)


# /usr/include/GL/freeglut_std.h 388
glutInitDisplayString = platform.createBaseFunction( 
    'glutInitDisplayString', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[STRING],
    doc='glutInitDisplayString( STRING(displayMode) ) -> None', 
    argNames=('displayMode',),
)


# /usr/include/GL/freeglut_std.h 385
glutInitWindowPosition = platform.createBaseFunction( 
    'glutInitWindowPosition', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int],
    doc='glutInitWindowPosition( c_int(x), c_int(y) ) -> None', 
    argNames=('x', 'y'),
)


# /usr/include/GL/freeglut_std.h 386
glutInitWindowSize = platform.createBaseFunction( 
    'glutInitWindowSize', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int],
    doc='glutInitWindowSize( c_int(width), c_int(height) ) -> None', 
    argNames=('width', 'height'),
)


# /usr/include/GL/freeglut_std.h 474
glutJoystickFunc = platform.createBaseFunction( 
    'glutJoystickFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_uint, c_int, c_int, c_int),c_int],
    doc='glutJoystickFunc( FUNCTION_TYPE(None, c_uint, c_int, c_int, c_int)(callback), c_int(pollInterval) ) -> None', 
    argNames=('callback', 'pollInterval'),
)


# /usr/include/GL/freeglut_std.h 462
glutKeyboardFunc = platform.createBaseFunction( 
    'glutKeyboardFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_ubyte, c_int, c_int)],
    doc='glutKeyboardFunc( FUNCTION_TYPE(None, c_ubyte, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 472
glutKeyboardUpFunc = platform.createBaseFunction( 
    'glutKeyboardUpFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_ubyte, c_int, c_int)],
    doc='glutKeyboardUpFunc( FUNCTION_TYPE(None, c_ubyte, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 494
glutLayerGet = platform.createBaseFunction( 
    'glutLayerGet', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[GLenum],
    doc='glutLayerGet( GLenum(query) ) -> c_int', 
    argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 538
glutLeaveGameMode = platform.createBaseFunction( 
    'glutLeaveGameMode', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutLeaveGameMode(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 393
glutMainLoop = platform.createBaseFunction( 
    'glutMainLoop', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutMainLoop(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 475
glutMenuStateFunc = platform.createBaseFunction( 
    'glutMenuStateFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int)],
    doc='glutMenuStateFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 476
glutMenuStatusFunc = platform.createBaseFunction( 
    'glutMenuStatusFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int)],
    doc='glutMenuStatusFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 468
glutMotionFunc = platform.createBaseFunction( 
    'glutMotionFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutMotionFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 467
glutMouseFunc = platform.createBaseFunction( 
    'glutMouseFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)],
    doc='glutMouseFunc( FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 477
glutOverlayDisplayFunc = platform.createBaseFunction( 
    'glutOverlayDisplayFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None)],
    doc='glutOverlayDisplayFunc( FUNCTION_TYPE(None)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 469
glutPassiveMotionFunc = platform.createBaseFunction( 
    'glutPassiveMotionFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutPassiveMotionFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 411
glutPopWindow = platform.createBaseFunction( 
    'glutPopWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutPopWindow(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 406
glutPositionWindow = platform.createBaseFunction( 
    'glutPositionWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int],
    doc='glutPositionWindow( c_int(x), c_int(y) ) -> None', 
    argNames=('x', 'y'),
)


# /usr/include/GL/freeglut_std.h 433
glutPostOverlayRedisplay = platform.createBaseFunction( 
    'glutPostOverlayRedisplay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutPostOverlayRedisplay(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 418
glutPostRedisplay = platform.createBaseFunction( 
    'glutPostRedisplay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutPostRedisplay(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 434
glutPostWindowOverlayRedisplay = platform.createBaseFunction( 
    'glutPostWindowOverlayRedisplay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutPostWindowOverlayRedisplay( c_int(window) ) -> None', 
    argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 417
glutPostWindowRedisplay = platform.createBaseFunction( 
    'glutPostWindowRedisplay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutPostWindowRedisplay( c_int(window) ) -> None', 
    argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 410
glutPushWindow = platform.createBaseFunction( 
    'glutPushWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutPushWindow(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 449
glutRemoveMenuItem = platform.createBaseFunction( 
    'glutRemoveMenuItem', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutRemoveMenuItem( c_int(item) ) -> None', 
    argNames=('item',),
)


# /usr/include/GL/freeglut_std.h 431
glutRemoveOverlay = platform.createBaseFunction( 
    'glutRemoveOverlay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutRemoveOverlay(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 568
glutReportErrors = platform.createBaseFunction( 
    'glutReportErrors', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutReportErrors(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 464
glutReshapeFunc = platform.createBaseFunction( 
    'glutReshapeFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutReshapeFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 405
glutReshapeWindow = platform.createBaseFunction( 
    'glutReshapeWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int],
    doc='glutReshapeWindow( c_int(width), c_int(height) ) -> None', 
    argNames=('width', 'height'),
)


# /usr/include/GL/freeglut_std.h 553
glutSetColor = platform.createBaseFunction( 
    'glutSetColor', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,GLfloat,GLfloat,GLfloat],
    doc='glutSetColor( c_int(color), GLfloat(red), GLfloat(green), GLfloat(blue) ) -> None', 
    argNames=('color', 'red', 'green', 'blue'),
)


# /usr/include/GL/freeglut_std.h 425
glutSetCursor = platform.createBaseFunction( 
    'glutSetCursor', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutSetCursor( c_int(cursor) ) -> None', 
    argNames=('cursor',),
)


# /usr/include/GL/freeglut_std.h 404
glutSetIconTitle = platform.createBaseFunction( 
    'glutSetIconTitle', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[STRING],
    doc='glutSetIconTitle( STRING(title) ) -> None', 
    argNames=('title',),
)


# /usr/include/GL/freeglut_std.h 561
glutSetKeyRepeat = platform.createBaseFunction( 
    'glutSetKeyRepeat', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutSetKeyRepeat( c_int(repeatMode) ) -> None', 
    argNames=('repeatMode',),
)


# /usr/include/GL/freeglut_std.h 444
glutSetMenu = platform.createBaseFunction( 
    'glutSetMenu', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutSetMenu( c_int(menu) ) -> None', 
    argNames=('menu',),
)


# /usr/include/GL/freeglut_std.h 401
glutSetWindow = platform.createBaseFunction( 
    'glutSetWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int],
    doc='glutSetWindow( c_int(window) ) -> None', 
    argNames=('window',),
)


# /usr/include/GL/freeglut_std.h 403
glutSetWindowTitle = platform.createBaseFunction( 
    'glutSetWindowTitle', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[STRING],
    doc='glutSetWindowTitle( STRING(title) ) -> None', 
    argNames=('title',),
)


# /usr/include/GL/freeglut_std.h 545
glutSetupVideoResizing = platform.createBaseFunction( 
    'glutSetupVideoResizing', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSetupVideoResizing(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 435
glutShowOverlay = platform.createBaseFunction( 
    'glutShowOverlay', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutShowOverlay(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 407
glutShowWindow = platform.createBaseFunction( 
    'glutShowWindow', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutShowWindow(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 514
glutSolidCone = platform.createBaseFunction( 
    'glutSolidCone', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLint,GLint],
    doc='glutSolidCone( GLdouble(base), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('base', 'height', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 510
glutSolidCube = platform.createBaseFunction( 
    'glutSolidCube', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble],
    doc='glutSolidCube( GLdouble(size) ) -> None', 
    argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 519
glutSolidDodecahedron = platform.createBaseFunction( 
    'glutSolidDodecahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSolidDodecahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 525
glutSolidIcosahedron = platform.createBaseFunction( 
    'glutSolidIcosahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSolidIcosahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 521
glutSolidOctahedron = platform.createBaseFunction( 
    'glutSolidOctahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSolidOctahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 512
glutSolidSphere = platform.createBaseFunction( 
    'glutSolidSphere', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble,GLint,GLint],
    doc='glutSolidSphere( GLdouble(radius), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('radius', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 531
glutSolidTeapot = platform.createBaseFunction( 
    'glutSolidTeapot', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble],
    doc='glutSolidTeapot( GLdouble(size) ) -> None', 
    argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 523
glutSolidTetrahedron = platform.createBaseFunction( 
    'glutSolidTetrahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSolidTetrahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 517
glutSolidTorus = platform.createBaseFunction( 
    'glutSolidTorus', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLint,GLint],
    doc='glutSolidTorus( GLdouble(innerRadius), GLdouble(outerRadius), GLint(sides), GLint(rings) ) -> None', 
    argNames=('innerRadius', 'outerRadius', 'sides', 'rings'),
)


# /usr/include/GL/freeglut_std.h 482
glutSpaceballButtonFunc = platform.createBaseFunction( 
    'glutSpaceballButtonFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutSpaceballButtonFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 480
glutSpaceballMotionFunc = platform.createBaseFunction( 
    'glutSpaceballMotionFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int)],
    doc='glutSpaceballMotionFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 481
glutSpaceballRotateFunc = platform.createBaseFunction( 
    'glutSpaceballRotateFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int)],
    doc='glutSpaceballRotateFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 463
glutSpecialFunc = platform.createBaseFunction( 
    'glutSpecialFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int)],
    doc='glutSpecialFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 473
glutSpecialUpFunc = platform.createBaseFunction( 
    'glutSpecialUpFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int)],
    doc='glutSpecialUpFunc( FUNCTION_TYPE(None, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 546
glutStopVideoResizing = platform.createBaseFunction( 
    'glutStopVideoResizing', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutStopVideoResizing(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 501
glutStrokeCharacter = platform.createBaseFunction( 
    'glutStrokeCharacter', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_void_p,c_int],
    doc='glutStrokeCharacter( c_void_p(font), c_int(character) ) -> None', 
    argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 504
glutStrokeLength = platform.createBaseFunction( 
    'glutStrokeLength', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[c_void_p,POINTER(c_ubyte)],
    doc='glutStrokeLength( c_void_p(font), POINTER(c_ubyte)(string) ) -> c_int', 
    argNames=('font', 'string'),
)


# /usr/include/GL/freeglut_std.h 502
glutStrokeWidth = platform.createBaseFunction( 
    'glutStrokeWidth', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[c_void_p,c_int],
    doc='glutStrokeWidth( c_void_p(font), c_int(character) ) -> c_int', 
    argNames=('font', 'character'),
)


# /usr/include/GL/freeglut_std.h 419
glutSwapBuffers = platform.createBaseFunction( 
    'glutSwapBuffers', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutSwapBuffers(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 486
glutTabletButtonFunc = platform.createBaseFunction( 
    'glutTabletButtonFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)],
    doc='glutTabletButtonFunc( FUNCTION_TYPE(None, c_int, c_int, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 485
glutTabletMotionFunc = platform.createBaseFunction( 
    'glutTabletMotionFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int, c_int)],
    doc='glutTabletMotionFunc( FUNCTION_TYPE(None, c_int, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 456
glutTimerFunc = platform.createBaseFunction( 
    'glutTimerFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_uint,CALLBACK_FUNCTION_TYPE(None, c_int),c_int],
    doc='glutTimerFunc( c_uint(time), FUNCTION_TYPE(None, c_int)(callback), c_int(value) ) -> None', 
    argNames=('time', 'callback', 'value'),
)


# /usr/include/GL/freeglut_std.h 432
glutUseLayer = platform.createBaseFunction( 
    'glutUseLayer', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLenum],
    doc='glutUseLayer( GLenum(layer) ) -> None', 
    argNames=('layer',),
)


# /usr/include/GL/freeglut_std.h 548
glutVideoPan = platform.createBaseFunction( 
    'glutVideoPan', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int,c_int,c_int],
    doc='glutVideoPan( c_int(x), c_int(y), c_int(width), c_int(height) ) -> None', 
    argNames=('x', 'y', 'width', 'height'),
)


# /usr/include/GL/freeglut_std.h 547
glutVideoResize = platform.createBaseFunction( 
    'glutVideoResize', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int,c_int,c_int],
    doc='glutVideoResize( c_int(x), c_int(y), c_int(width), c_int(height) ) -> None', 
    argNames=('x', 'y', 'width', 'height'),
)


# /usr/include/GL/freeglut_std.h 544
glutVideoResizeGet = platform.createBaseFunction( 
    'glutVideoResizeGet', dll=platform.PLATFORM.GLUT, resultType=c_int, 
    argTypes=[GLenum],
    doc='glutVideoResizeGet( GLenum(query) ) -> c_int', 
    argNames=('query',),
)


# /usr/include/GL/freeglut_std.h 465
glutVisibilityFunc = platform.createBaseFunction( 
    'glutVisibilityFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int)],
    doc='glutVisibilityFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 424
glutWarpPointer = platform.createBaseFunction( 
    'glutWarpPointer', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[c_int,c_int],
    doc='glutWarpPointer( c_int(x), c_int(y) ) -> None', 
    argNames=('x', 'y'),
)


# /usr/include/GL/freeglut_std.h 478
glutWindowStatusFunc = platform.createBaseFunction( 
    'glutWindowStatusFunc', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[CALLBACK_FUNCTION_TYPE(None, c_int)],
    doc='glutWindowStatusFunc( FUNCTION_TYPE(None, c_int)(callback) ) -> None', 
    argNames=('callback',),
)


# /usr/include/GL/freeglut_std.h 513
glutWireCone = platform.createBaseFunction( 
    'glutWireCone', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLint,GLint],
    doc='glutWireCone( GLdouble(base), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('base', 'height', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 509
glutWireCube = platform.createBaseFunction( 
    'glutWireCube', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble],
    doc='glutWireCube( GLdouble(size) ) -> None', 
    argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 518
glutWireDodecahedron = platform.createBaseFunction( 
    'glutWireDodecahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutWireDodecahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 524
glutWireIcosahedron = platform.createBaseFunction( 
    'glutWireIcosahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutWireIcosahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 520
glutWireOctahedron = platform.createBaseFunction( 
    'glutWireOctahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutWireOctahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 511
glutWireSphere = platform.createBaseFunction( 
    'glutWireSphere', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble,GLint,GLint],
    doc='glutWireSphere( GLdouble(radius), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('radius', 'slices', 'stacks'),
)


# /usr/include/GL/freeglut_std.h 530
glutWireTeapot = platform.createBaseFunction( 
    'glutWireTeapot', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble],
    doc='glutWireTeapot( GLdouble(size) ) -> None', 
    argNames=('size',),
)


# /usr/include/GL/freeglut_std.h 522
glutWireTetrahedron = platform.createBaseFunction( 
    'glutWireTetrahedron', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[],
    doc='glutWireTetrahedron(  ) -> None', 
    argNames=(),
)


# /usr/include/GL/freeglut_std.h 516
glutWireTorus = platform.createBaseFunction( 
    'glutWireTorus', dll=platform.PLATFORM.GLUT, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLint,GLint],
    doc='glutWireTorus( GLdouble(innerRadius), GLdouble(outerRadius), GLint(sides), GLint(rings) ) -> None', 
    argNames=('innerRadius', 'outerRadius', 'sides', 'rings'),
)

__all__ = [
    'GLUT_ACCUM',
    'GLUT_ACTIVE_ALT',
    'GLUT_ACTIVE_CTRL',
    'GLUT_ACTIVE_SHIFT',
    'GLUT_ALPHA',
    'GLUT_API_VERSION',
    'GLUT_BLUE',
    'GLUT_CURSOR_BOTTOM_LEFT_CORNER',
    'GLUT_CURSOR_BOTTOM_RIGHT_CORNER',
    'GLUT_CURSOR_BOTTOM_SIDE',
    'GLUT_CURSOR_CROSSHAIR',
    'GLUT_CURSOR_CYCLE',
    'GLUT_CURSOR_DESTROY',
    'GLUT_CURSOR_FULL_CROSSHAIR',
    'GLUT_CURSOR_HELP',
    'GLUT_CURSOR_INFO',
    'GLUT_CURSOR_INHERIT',
    'GLUT_CURSOR_LEFT_ARROW',
    'GLUT_CURSOR_LEFT_RIGHT',
    'GLUT_CURSOR_LEFT_SIDE',
    'GLUT_CURSOR_NONE',
    'GLUT_CURSOR_RIGHT_ARROW',
    'GLUT_CURSOR_RIGHT_SIDE',
    'GLUT_CURSOR_SPRAY',
    'GLUT_CURSOR_TEXT',
    'GLUT_CURSOR_TOP_LEFT_CORNER',
    'GLUT_CURSOR_TOP_RIGHT_CORNER',
    'GLUT_CURSOR_TOP_SIDE',
    'GLUT_CURSOR_UP_DOWN',
    'GLUT_CURSOR_WAIT',
    'GLUT_DEPTH',
    'GLUT_DEVICE_IGNORE_KEY_REPEAT',
    'GLUT_DEVICE_KEY_REPEAT',
    'GLUT_DISPLAY_MODE_POSSIBLE',
    'GLUT_DOUBLE',
    'GLUT_DOWN',
    'GLUT_ELAPSED_TIME',
    'GLUT_ENTERED',
    'GLUT_FULLY_COVERED',
    'GLUT_FULLY_RETAINED',
    'GLUT_GAME_MODE_ACTIVE',
    'GLUT_GAME_MODE_DISPLAY_CHANGED',
    'GLUT_GAME_MODE_HEIGHT',
    'GLUT_GAME_MODE_PIXEL_DEPTH',
    'GLUT_GAME_MODE_POSSIBLE',
    'GLUT_GAME_MODE_REFRESH_RATE',
    'GLUT_GAME_MODE_WIDTH',
    'GLUT_GREEN',
    'GLUT_HAS_DIAL_AND_BUTTON_BOX',
    'GLUT_HAS_JOYSTICK',
    'GLUT_HAS_KEYBOARD',
    'GLUT_HAS_MOUSE',
    'GLUT_HAS_OVERLAY',
    'GLUT_HAS_SPACEBALL',
    'GLUT_HAS_TABLET',
    'GLUT_HIDDEN',
    'GLUT_INDEX',
    'GLUT_INIT_DISPLAY_MODE',
    'GLUT_INIT_STATE',
    'GLUT_INIT_WINDOW_HEIGHT',
    'GLUT_INIT_WINDOW_WIDTH',
    'GLUT_INIT_WINDOW_X',
    'GLUT_INIT_WINDOW_Y',
    'GLUT_JOYSTICK_AXES',
    'GLUT_JOYSTICK_BUTTONS',
    'GLUT_JOYSTICK_BUTTON_A',
    'GLUT_JOYSTICK_BUTTON_B',
    'GLUT_JOYSTICK_BUTTON_C',
    'GLUT_JOYSTICK_BUTTON_D',
    'GLUT_JOYSTICK_POLL_RATE',
    'GLUT_KEY_DOWN',
    'GLUT_KEY_END',
    'GLUT_KEY_F1',
    'GLUT_KEY_F10',
    'GLUT_KEY_F11',
    'GLUT_KEY_F12',
    'GLUT_KEY_F2',
    'GLUT_KEY_F3',
    'GLUT_KEY_F4',
    'GLUT_KEY_F5',
    'GLUT_KEY_F6',
    'GLUT_KEY_F7',
    'GLUT_KEY_F8',
    'GLUT_KEY_F9',
    'GLUT_KEY_HOME',
    'GLUT_KEY_INSERT',
    'GLUT_KEY_LEFT',
    'GLUT_KEY_PAGE_DOWN',
    'GLUT_KEY_PAGE_UP',
    'GLUT_KEY_REPEAT_DEFAULT',
    'GLUT_KEY_REPEAT_OFF',
    'GLUT_KEY_REPEAT_ON',
    'GLUT_KEY_RIGHT',
    'GLUT_KEY_UP',
    'GLUT_LAYER_IN_USE',
    'GLUT_LEFT',
    'GLUT_LEFT_BUTTON',
    'GLUT_LUMINANCE',
    'GLUT_MENU_IN_USE',
    'GLUT_MENU_NOT_IN_USE',
    'GLUT_MENU_NUM_ITEMS',
    'GLUT_MIDDLE_BUTTON',
    'GLUT_MULTISAMPLE',
    'GLUT_NORMAL',
    'GLUT_NORMAL_DAMAGED',
    'GLUT_NOT_VISIBLE',
    'GLUT_NUM_BUTTON_BOX_BUTTONS',
    'GLUT_NUM_DIALS',
    'GLUT_NUM_MOUSE_BUTTONS',
    'GLUT_NUM_SPACEBALL_BUTTONS',
    'GLUT_NUM_TABLET_BUTTONS',
    'GLUT_OVERLAY',
    'GLUT_OVERLAY_DAMAGED',
    'GLUT_OVERLAY_POSSIBLE',
    'GLUT_OWNS_JOYSTICK',
    'GLUT_PARTIALLY_RETAINED',
    'GLUT_RED',
    'GLUT_RGB',
    'GLUT_RGBA',
    'GLUT_RIGHT_BUTTON',
    'GLUT_SCREEN_HEIGHT',
    'GLUT_SCREEN_HEIGHT_MM',
    'GLUT_SCREEN_WIDTH',
    'GLUT_SCREEN_WIDTH_MM',
    'GLUT_SINGLE',
    'GLUT_STENCIL',
    'GLUT_STEREO',
    'GLUT_TRANSPARENT_INDEX',
    'GLUT_UP',
    'GLUT_VIDEO_RESIZE_HEIGHT',
    'GLUT_VIDEO_RESIZE_HEIGHT_DELTA',
    'GLUT_VIDEO_RESIZE_IN_USE',
    'GLUT_VIDEO_RESIZE_POSSIBLE',
    'GLUT_VIDEO_RESIZE_WIDTH',
    'GLUT_VIDEO_RESIZE_WIDTH_DELTA',
    'GLUT_VIDEO_RESIZE_X',
    'GLUT_VIDEO_RESIZE_X_DELTA',
    'GLUT_VIDEO_RESIZE_Y',
    'GLUT_VIDEO_RESIZE_Y_DELTA',
    'GLUT_VISIBLE',
    'GLUT_WINDOW_ACCUM_ALPHA_SIZE',
    'GLUT_WINDOW_ACCUM_BLUE_SIZE',
    'GLUT_WINDOW_ACCUM_GREEN_SIZE',
    'GLUT_WINDOW_ACCUM_RED_SIZE',
    'GLUT_WINDOW_ALPHA_SIZE',
    'GLUT_WINDOW_BLUE_SIZE',
    'GLUT_WINDOW_BUFFER_SIZE',
    'GLUT_WINDOW_COLORMAP_SIZE',
    'GLUT_WINDOW_CURSOR',
    'GLUT_WINDOW_DEPTH_SIZE',
    'GLUT_WINDOW_DOUBLEBUFFER',
    'GLUT_WINDOW_FORMAT_ID',
    'GLUT_WINDOW_GREEN_SIZE',
    'GLUT_WINDOW_HEIGHT',
    'GLUT_WINDOW_NUM_CHILDREN',
    'GLUT_WINDOW_NUM_SAMPLES',
    'GLUT_WINDOW_PARENT',
    'GLUT_WINDOW_RED_SIZE',
    'GLUT_WINDOW_RGBA',
    'GLUT_WINDOW_STENCIL_SIZE',
    'GLUT_WINDOW_STEREO',
    'GLUT_WINDOW_WIDTH',
    'GLUT_WINDOW_X',
    'GLUT_WINDOW_Y',
    'GLUT_XLIB_IMPLEMENTATION',
    'GLdouble',
    'GLenum',
    'GLfloat',
    'GLint',
    'glutAddMenuEntry',
    'glutAddSubMenu',
    'glutAttachMenu',
    'glutBitmapCharacter',
    'glutBitmapLength',
    'glutBitmapWidth',
    'glutButtonBoxFunc',
    'glutChangeToMenuEntry',
    'glutChangeToSubMenu',
    'glutCopyColormap',
    'glutCreateMenu',
    'glutCreateSubWindow',
    'glutCreateWindow',
    'glutDestroyMenu',
    'glutDestroyWindow',
    'glutDetachMenu',
    'glutDeviceGet',
    'glutDialsFunc',
    'glutDisplayFunc',
    'glutEnterGameMode',
    'glutEntryFunc',
    'glutEstablishOverlay',
    'glutExtensionSupported',
    'glutForceJoystickFunc',
    'glutFullScreen',
    'glutGameModeGet',
    'glutGameModeString',
    'glutGet',
    'glutGetColor',
    'glutGetMenu',
    'glutGetModifiers',
    'glutGetWindow',
    'glutHideOverlay',
    'glutHideWindow',
    'glutIconifyWindow',
    'glutIdleFunc',
    'glutIgnoreKeyRepeat',
    'glutInit',
    'glutInitDisplayMode',
    'glutInitDisplayString',
    'glutInitWindowPosition',
    'glutInitWindowSize',
    'glutJoystickFunc',
    'glutKeyboardFunc',
    'glutKeyboardUpFunc',
    'glutLayerGet',
    'glutLeaveGameMode',
    'glutMainLoop',
    'glutMenuStateFunc',
    'glutMenuStatusFunc',
    'glutMotionFunc',
    'glutMouseFunc',
    'glutOverlayDisplayFunc',
    'glutPassiveMotionFunc',
    'glutPopWindow',
    'glutPositionWindow',
    'glutPostOverlayRedisplay',
    'glutPostRedisplay',
    'glutPostWindowOverlayRedisplay',
    'glutPostWindowRedisplay',
    'glutPushWindow',
    'glutRemoveMenuItem',
    'glutRemoveOverlay',
    'glutReportErrors',
    'glutReshapeFunc',
    'glutReshapeWindow',
    'glutSetColor',
    'glutSetCursor',
    'glutSetIconTitle',
    'glutSetKeyRepeat',
    'glutSetMenu',
    'glutSetWindow',
    'glutSetWindowTitle',
    'glutSetupVideoResizing',
    'glutShowOverlay',
    'glutShowWindow',
    'glutSolidCone',
    'glutSolidCube',
    'glutSolidDodecahedron',
    'glutSolidIcosahedron',
    'glutSolidOctahedron',
    'glutSolidSphere',
    'glutSolidTeapot',
    'glutSolidTetrahedron',
    'glutSolidTorus',
    'glutSpaceballButtonFunc',
    'glutSpaceballMotionFunc',
    'glutSpaceballRotateFunc',
    'glutSpecialFunc',
    'glutSpecialUpFunc',
    'glutStopVideoResizing',
    'glutStrokeCharacter',
    'glutStrokeLength',
    'glutStrokeWidth',
    'glutSwapBuffers',
    'glutTabletButtonFunc',
    'glutTabletMotionFunc',
    'glutTimerFunc',
    'glutUseLayer',
    'glutVideoPan',
    'glutVideoResize',
    'glutVideoResizeGet',
    'glutVisibilityFunc',
    'glutWarpPointer',
    'glutWindowStatusFunc',
    'glutWireCone',
    'glutWireCube',
    'glutWireDodecahedron',
    'glutWireIcosahedron',
    'glutWireOctahedron',
    'glutWireSphere',
    'glutWireTeapot',
    'glutWireTetrahedron',
    'glutWireTorus'
]



'''OpenGL extension EXT.shader_image_load_store

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.shader_image_load_store to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides GLSL built-in functions allowing shaders to load
	from, store to, and perform atomic read-modify-write operations to a
	single level of a texture object from any shader stage.  These built-in
	functions are named imageLoad(), imageStore(), and imageAtomic*(),
	respectively, and accept integer texel coordinates to identify the texel
	accessed.  The extension adds the notion of "image units" to the OpenGL
	API, to which texture levels are bound for access by the GLSL built-in
	functions.  To allow shaders to specify the image unit to access, GLSL
	provides a new set of data types ("image*") similar to samplers.  Each
	image variable is assigned an integer value to identify an image unit to
	access, which is specified using Uniform*() APIs in a manner similar to
	samplers.  For implementations supporting the NV_gpu_program5 extensions,
	assembly language instructions to perform image loads, stores, and atomics
	are also provided.
	
	This extension also provides the capability to explicitly enable "early"
	per-fragment tests, where operations like depth and stencil testing are
	performed prior to fragment shader execution.  In unextended OpenGL,
	fragment shaders never have any side effects and implementations can
	sometimes perform per-fragment tests and discard some fragments prior to
	executing the fragment shader.  Since this extension allows fragment
	shaders to write to texture and buffer object memory using the built-in
	image functions, such optimizations could lead to non-deterministic
	results.  To avoid this, implementations supporting this extension may not
	perform such optimizations on shaders having such side effects.  However,
	enabling early per-fragment tests guarantees that such tests will be
	performed prior to fragment shader execution, and ensures that image
	stores and atomics will not be performed by fragment shader invocations
	where these per-fragment tests fail.
	
	Finally, this extension provides both a GLSL built-in function and an
	OpenGL API function allowing applications some control over the ordering
	of image loads, stores, and atomics relative to other OpenGL pipeline
	operations accessing the same memory.  Because the extension provides the
	ability to perform random accesses to texture or buffer object memory,
	such accesses are not easily tracked by the OpenGL driver.  To avoid the
	need for heavy-handed synchronization at the driver level, this extension
	requires manual synchronization.  The MemoryBarrierEXT() OpenGL API
	function allows applications to specify a bitfield indicating the set of
	OpenGL API operations to synchronize relative to shader memory access.
	The memoryBarrier() GLSL built-in function provides a synchronization
	point within a given shader invocation to ensure that all memory accesses
	performed prior to the synchronization point complete prior to any started
	after the synchronization point.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shader_image_load_store.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.shader_image_load_store import *
from OpenGL.raw.GL.EXT.shader_image_load_store import _EXTENSION_NAME

def glInitShaderImageLoadStoreEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.debug_output

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.debug_output to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows the GL to notify applications when various
	debug events occur in contexts that have been created with the debug
	flag, as provided by WGL_ARB_create_context and GLX_ARB_create_context.
	
	These events are represented in the form of enumerable messages with an
	included human-readable translation.  Examples of debug events include
	incorrect use of the GL, warnings of undefined behavior, and performance
	warnings.
	
	A message is uniquely identified by a category and an implementation-
	dependent ID within that category.  Message categories are general and are
	used to organize large groups of similar messages together.  Examples of
	categories include GL errors, performance warnings, and deprecated
	functionality warnings.  Each message is also assigned a severity level
	that denotes roughly how "important" that message is in comparison to
	other messages across all categories.  For example, notification of a GL
	error would have a higher severity than a performance warning due to
	redundant state changes.
	
	Messages are communicated to the application through an application-defined
	callback function that is called by the GL implementation on each debug
	message.  The motivation for the callback routine is to free application
	developers from actively having to query whether any GL error or other
	debuggable event has happened after each call to a GL function.  With a
	callback, developers can keep their code free of debug checks, and only have
	to react to messages as they occur.  In order to support indirect rendering,
	a message log is also provided that stores copies of recent messages until
	they are actively queried.
	
	To control the volume of debug output, messages can be disabled either
	individually by ID, or entire groups of messages can be turned off based
	on category or severity.
	
	The only requirement on the minimum quantity and type of messages that
	implementations of this extension must support is that a message must be
	sent notifying the application whenever any GL error occurs.  Any further
	messages are left to the implementation.  Implementations do not have
	to output messages from all categories listed by this extension
	in order to support this extension, and new categories can be added by
	other extensions.
	
	This extension places no restrictions or requirements on any additional
	functionality provided by the debug context flag through other extensions. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/debug_output.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.debug_output import *
from OpenGL.raw.GL.AMD.debug_output import _EXTENSION_NAME

def glInitDebugOutputAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDebugMessageEnableAMD.ids size not checked against count
glDebugMessageEnableAMD=wrapper.wrapper(glDebugMessageEnableAMD).setInputArraySize(
    'ids', None
)
# INPUT glDebugMessageInsertAMD.buf size not checked against length
glDebugMessageInsertAMD=wrapper.wrapper(glDebugMessageInsertAMD).setInputArraySize(
    'buf', None
)
# glDebugMessageCallbackAMD.userParam is OUTPUT without known output size
glGetDebugMessageLogAMD=wrapper.wrapper(glGetDebugMessageLogAMD).setOutput(
    'categories',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'ids',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'lengths',size=lambda x:(x,),pnameArg='count',orPassIn=True
).setOutput(
    'message',size=lambda x:(x,),pnameArg='bufsize',orPassIn=True
).setOutput(
    'severities',size=lambda x:(x,),pnameArg='count',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_fog_coord'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_fog_coord',error_checker=_errors._error_checker)
GL_CURRENT_FOG_COORDINATE_EXT=_C('GL_CURRENT_FOG_COORDINATE_EXT',0x8453)
GL_FOG_COORDINATE_ARRAY_EXT=_C('GL_FOG_COORDINATE_ARRAY_EXT',0x8457)
GL_FOG_COORDINATE_ARRAY_POINTER_EXT=_C('GL_FOG_COORDINATE_ARRAY_POINTER_EXT',0x8456)
GL_FOG_COORDINATE_ARRAY_STRIDE_EXT=_C('GL_FOG_COORDINATE_ARRAY_STRIDE_EXT',0x8455)
GL_FOG_COORDINATE_ARRAY_TYPE_EXT=_C('GL_FOG_COORDINATE_ARRAY_TYPE_EXT',0x8454)
GL_FOG_COORDINATE_EXT=_C('GL_FOG_COORDINATE_EXT',0x8451)
GL_FOG_COORDINATE_SOURCE_EXT=_C('GL_FOG_COORDINATE_SOURCE_EXT',0x8450)
GL_FRAGMENT_DEPTH_EXT=_C('GL_FRAGMENT_DEPTH_EXT',0x8452)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glFogCoordPointerEXT(type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLdouble)
def glFogCoorddEXT(coord):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glFogCoorddvEXT(coord):pass
@_f
@_p.types(None,_cs.GLfloat)
def glFogCoordfEXT(coord):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glFogCoordfvEXT(coord):pass



'''OpenGL extension NV.evaluators

This module customises the behaviour of the 
OpenGL.raw.GL.NV.evaluators to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL evaluators provide applications with the capability to
	specify polynomial or rational curves and surfaces using control
	points relative to the Bezier basis.  The curves and surfaces are
	then drawn by evaluating the polynomials provided at various values
	for the u parameter of a curve or the (u,v) parameters of a surface.
	A tensor product formulation is used for the surfaces.
	
	For various historical reasons, evaluators have not been
	particularly popular as an interface for drawing curves and surfaces.
	This extension proposes a new interface for surfaces that provides a
	number of significant enhancements to the functionality provided by
	the original OpenGL evaluators.
	
	Many implementations never optimized evaluators, so applications
	often implemented their own algorithms instead.  This extension
	relaxes some restrictions that make it difficult to optimize
	evaluators.
	
	Also, new vertex attributes have been added to OpenGL through
	extensions, including multiple sets of texture coordinates, a
	secondary color, a fog coordinate, a vertex weight, and others.
	The extensions which added these vertex attributes never bothered
	to update the functionality of evaluators, since they were used so
	little in the first place.  In turn, evaluators have become more and
	more out of date, making it even less likely that developers will
	want to use them.  Most of the attributes are not a big loss, but
	support for multiple sets of texture coordinates would be absolutely
	essential to developers considering the use of evaluators.
	
	OpenGL evaluators only support rectangular patches, not triangular
	patches.  Although triangular patches can be converted into
	rectangular patches, direct support for triangular patches is likely
	to be more efficient.
	
	The tessellation algorithm used is too inflexible for most purposes;
	only the number of rows and columns can be specified.  Adjacent
	patches must then have identical numbers of rows and columns, or
	severe cracking will occur.  Ideally, a number of subdivisions could
	be specified for all four sides of a rectangular patch and for all
	three of a triangular patch.  This extension goes one step further
	and allows those numbers to be specified in floating-point, providing
	a mechanism for smoothly changing the level of detail of the surface.
	
	Meshes evaluated with EvalMesh are required to match up exactly
	with equivalent meshes evaluated with EvalCoord or EvalPoint.
	This makes it difficult or impossible to use optimizations such as
	forward differencing.
	
	Finally, little attention is given to some of the difficult problems
	that can arise when multiple patches are drawn.  Depending on the
	way evaluators are implemented, and depending on the orientation of
	edges, numerical accuracy problems can cause cracks to appear between
	patches with the same boundary control points.  This extension makes
	guarantees that an edge shared between two patches will match up
	exactly under certain conditions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/evaluators.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.evaluators import *
from OpenGL.raw.GL.NV.evaluators import _EXTENSION_NAME

def glInitEvaluatorsNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glMapControlPointsNV.points size not checked against 'target,uorder,vorder'
glMapControlPointsNV=wrapper.wrapper(glMapControlPointsNV).setInputArraySize(
    'points', None
)
# INPUT glMapParameterivNV.params size not checked against 'target,pname'
glMapParameterivNV=wrapper.wrapper(glMapParameterivNV).setInputArraySize(
    'params', None
)
# INPUT glMapParameterfvNV.params size not checked against 'target,pname'
glMapParameterfvNV=wrapper.wrapper(glMapParameterfvNV).setInputArraySize(
    'params', None
)
glGetMapControlPointsNV=wrapper.wrapper(glGetMapControlPointsNV).setOutput(
    'points',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
# OUTPUT glGetMapParameterivNV.params COMPSIZE(target, pname) 
# OUTPUT glGetMapParameterfvNV.params COMPSIZE(target, pname) 
glGetMapAttribParameterivNV=wrapper.wrapper(glGetMapAttribParameterivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetMapAttribParameterfvNV=wrapper.wrapper(glGetMapAttribParameterfvNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.color_subtable

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.color_subtable to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows a portion of a color table to be redefined.
	If EXT_copy_texture is implemented, this extension also defines a
	method to load a portion of a color lookup table from the 
	framebuffer.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/color_subtable.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.color_subtable import *
from OpenGL.raw.GL.EXT.color_subtable import _EXTENSION_NAME

def glInitColorSubtableEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glColorSubTableEXT.data size not checked against 'format,type,count'
glColorSubTableEXT=wrapper.wrapper(glColorSubTableEXT).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_NV_video_capture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_NV_video_capture',error_checker=_errors._error_checker)
GLX_DEVICE_ID_NV=_C('GLX_DEVICE_ID_NV',0x20CD)
GLX_NUM_VIDEO_CAPTURE_SLOTS_NV=_C('GLX_NUM_VIDEO_CAPTURE_SLOTS_NV',0x20CF)
GLX_UNIQUE_ID_NV=_C('GLX_UNIQUE_ID_NV',0x20CE)
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_uint,_cs.GLXVideoCaptureDeviceNV)
def glXBindVideoCaptureDeviceNV(dpy,video_capture_slot,device):pass
@_f
@_p.types(ctypes.POINTER(_cs.GLXVideoCaptureDeviceNV),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXEnumerateVideoCaptureDevicesNV(dpy,screen,nelements):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXVideoCaptureDeviceNV)
def glXLockVideoCaptureDeviceNV(dpy,device):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXVideoCaptureDeviceNV,_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXQueryVideoCaptureDeviceNV(dpy,device,attribute,value):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXVideoCaptureDeviceNV)
def glXReleaseVideoCaptureDeviceNV(dpy,device):pass



'''OpenGL extension AMD.gpu_shader_int64

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.gpu_shader_int64 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension was developed based on the NV_gpu_shader5 extension to
	allow implementations supporting 64-bit integers to expose the feature
	without the additional requirements that are present in NV_gpu_shader5.
	
	The extension introduces the following features for all shader types:
	
	  * support for 64-bit scalar and vector integer data types, including
	    uniform API, uniform buffer object, transform feedback, and shader
	    input and output support;
	
	  * new built-in functions to pack and unpack 64-bit integer types into a
	    two-component 32-bit integer vector;
	
	  * new built-in functions to convert double-precision floating-point
	    values to or from their 64-bit integer bit encodings;
	
	  * vector relational functions supporting comparisons of vectors of
	    64-bit integer types; and
	
	  * common functions abs, sign, min, max, clamp, and mix supporting
	    arguments of 64-bit integer types.
	
	This extension is designed to be a functional superset of the 64-bit
	integer support introduced by NV_gpu_shader5 and to be source code
	compatible with that, thus the new procedures, functions, and tokens
	are identical to those found in that extension.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/gpu_shader_int64.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.gpu_shader_int64 import *
from OpenGL.raw.GL.AMD.gpu_shader_int64 import _EXTENSION_NAME

def glInitGpuShaderInt64AMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glUniform1i64vNV.value size not checked against count
glUniform1i64vNV=wrapper.wrapper(glUniform1i64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform2i64vNV.value size not checked against count*2
glUniform2i64vNV=wrapper.wrapper(glUniform2i64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform3i64vNV.value size not checked against count*3
glUniform3i64vNV=wrapper.wrapper(glUniform3i64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform4i64vNV.value size not checked against count*4
glUniform4i64vNV=wrapper.wrapper(glUniform4i64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform1ui64vNV.value size not checked against count
glUniform1ui64vNV=wrapper.wrapper(glUniform1ui64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform2ui64vNV.value size not checked against count*2
glUniform2ui64vNV=wrapper.wrapper(glUniform2ui64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform3ui64vNV.value size not checked against count*3
glUniform3ui64vNV=wrapper.wrapper(glUniform3ui64vNV).setInputArraySize(
    'value', None
)
# INPUT glUniform4ui64vNV.value size not checked against count*4
glUniform4ui64vNV=wrapper.wrapper(glUniform4ui64vNV).setInputArraySize(
    'value', None
)
# OUTPUT glGetUniformi64vNV.params COMPSIZE(program, location) 
# OUTPUT glGetUniformui64vNV.params COMPSIZE(program, location) 
# INPUT glProgramUniform1i64vNV.value size not checked against count
glProgramUniform1i64vNV=wrapper.wrapper(glProgramUniform1i64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform2i64vNV.value size not checked against count*2
glProgramUniform2i64vNV=wrapper.wrapper(glProgramUniform2i64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform3i64vNV.value size not checked against count*3
glProgramUniform3i64vNV=wrapper.wrapper(glProgramUniform3i64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform4i64vNV.value size not checked against count*4
glProgramUniform4i64vNV=wrapper.wrapper(glProgramUniform4i64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform1ui64vNV.value size not checked against count
glProgramUniform1ui64vNV=wrapper.wrapper(glProgramUniform1ui64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform2ui64vNV.value size not checked against count*2
glProgramUniform2ui64vNV=wrapper.wrapper(glProgramUniform2ui64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform3ui64vNV.value size not checked against count*3
glProgramUniform3ui64vNV=wrapper.wrapper(glProgramUniform3ui64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniform4ui64vNV.value size not checked against count*4
glProgramUniform4ui64vNV=wrapper.wrapper(glProgramUniform4ui64vNV).setInputArraySize(
    'value', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.ycbcr_422

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.ycbcr_422 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a method for GL to read, store and optionally
	process textures that are defined in Y'CbCr 422 video formats.  This
	extension supports the two common Y'CbCr 422 video formats (known by
	QuickTime FourCC as '2vuy' and 'yuvs'). These formats represent one of the
	most common 16 bit Y'CbCr formats in both standard and reverse byte
	ordering. From a client stand point these can be assumed to be decoded
	immediately (even though the implementation is free to optimize the data
	storage and keep it in the native format) and otherwise function as any
	other texture format.  The texture command <internalformat> parameter
	normally be should be specified as RGB, since Y'CbCr is just a form of RGB
	data.  This extension can be supported with either hardware or software
	decoding and it is up to the specific implementation to determine which is
	used.
	
	A new <format> is added, YCBCR_422_APPLE.  Additionally, to handle the
	difference in pixel size and byte ordering for 422 video, the pixel storage
	operations treat YCBCR_422_APPLE as a 2 component format using
	the UNSIGNED_SHORT_8_8_APPLE or UNSIGNED_SHORT_8_8_REV_APPLE <type>.
	
	The '2vuy' or k2vuyPixelFormat pixel format is an 8-bit 4:2:2 Component
	Y'CbCr format. Each 16 bit pixel is represented by an unsigned eight bit
	luminance component and two unsigned eight bit chroma components. Each pair
	of pixels shares a common set of chroma values. The components are ordered
	in memory; Cb, Y0, Cr, Y1. The luminance components have a range of [16,
	235], while the chroma value has a range of [16, 240]. This is consistent
	with the CCIR601 spec. This format is fairly prevalent on both Mac and Win32
	platforms. The equivalent Microsoft fourCC is OUYVYO.  This format is
	supported with the UNSIGNED_SHORT_8_8_REV_APPLE type for pixel storage
	operations.
	
	The 'yuvs' or kYUVSPixelFormat is an 8-bit 4:2:2 Component Y'CbCr format.
	Identical to the k2vuyPixelFormat except each 16 bit word has been byte
	swapped. This results in a component ordering of; Y0, Cb, Y1, Cr. This is
	most prevalent yuv 4:2:2 format on both Mac and Win32 platforms. The
	equivalent Microsoft fourCC is 'YUY2'.  This format is supported with the
	UNSIGNED_SHORT_8_8_APPLE type for pixel storage operations.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/ycbcr_422.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.ycbcr_422 import *
from OpenGL.raw.GL.APPLE.ycbcr_422 import _EXTENSION_NAME

def glInitYcbcr422APPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION